@@ -10,6 +10,7 @@
 //! **Note:** This may move as string-cache becomes less Web-specific.
 
 use atom::Atom;
+use std::fmt;
 use std::ops;
 
 /// An atom that is meant to represent a namespace in the HTML / XML sense.
@@ -36,6 +37,13 @@ impl<'a> PartialEq<Namespace> for BorrowedNamespace<'a> {
     }
 }
 
+impl fmt::Display for Namespace {
+    #[inline]
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        <str as fmt::Display>::fmt(&self.0, f)
+    }
+}
+
 /// A name with a namespace.
 #[derive(PartialEq, Eq, PartialOrd, Ord, Hash, Debug, Clone)]
 pub struct QualName {
