@@ -902,6 +902,7 @@ pub static ATOMS: &'static [&'static str] = &[
     "onstop",
     "onstorage",
     "onsubmit",
+    "ontransitionend",
     "onunload",
     "onzoom",
     "opacity",
@@ -1177,8 +1178,9 @@ pub static ATOMS: &'static [&'static str] = &[
     "transition-delay",
     "transition-duration",
     "transition-property",
-    "transitions",
     "transition-timing-function",
+    "transitionend",
+    "transitions",
     "transpose",
     "tref",
     "true",
